@@ -24,5 +24,12 @@
 #define SPECIFY_FLAG_STAT 9
 #define NOT_GROUP_OPTION 10
 #define SPECIFY_GROUP 11
+#define INVALID_NUMERIC_VALUE 12
+#define INVALID_ENUM_TYPE_USE 13
+#define MODE_UNDEFINED 14
+#define NOT_MODE_OPTION 15
+#define SPECIFY_MODE 16
+#define HELP_REDEFINED 17
+#define VERSION_REDEFINED 18
 
 #endif
