@@ -146,12 +146,15 @@
 /* Copy the first part of user declarations.  */
 #line 22 "parser.yy"
 
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 
-#include "strdup.h"
-
 #include "my_sstream.h"
 
 #include "acceptedvalues.h"
@@ -172,16 +175,18 @@ static int gengetopt_purpose_given = 0;
 static int gengetopt_usage_given = 0;
 static int gengetopt_description_given = 0;
 
-extern int yylex () ;
+extern int yylex (void) ;
 
 //#define YYERROR_VERBOSE 1
 
 void check_result(int o, gengetopt_option *opt)
 {
-    if (o) {
+  if (o)
+    {
         ostringstream err;
 
-	switch (o) {
+    switch (o)
+    {
     case NOT_ENOUGH_MEMORY:
         yyerror (opt, "not enough memory");
     	break;
@@ -282,7 +287,7 @@ struct multiple_size
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 139 "parser.yy"
+#line 144 "parser.yy"
 {
     char   *str;
     char    chr;
@@ -293,7 +298,7 @@ typedef union YYSTYPE
     struct multiple_size *multiple_size;
 }
 /* Line 187 of yacc.c.  */
-#line 297 "parser.cc"
+#line 302 "parser.cc"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -318,7 +323,7 @@ typedef struct YYLTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 322 "parser.cc"
+#line 327 "parser.cc"
 
 #ifdef short
 # undef short
@@ -631,13 +636,13 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   200,   200,   202,   207,   208,   209,   210,   211,   212,
-     213,   214,   215,   216,   217,   218,   219,   224,   244,   264,
-     284,   304,   325,   332,   339,   346,   356,   366,   385,   404,
-     426,   429,   435,   440,   445,   450,   455,   460,   465,   470,
-     475,   480,   488,   493,   498,   503,   507,   508,   512,   513,
-     514,   518,   519,   523,   524,   528,   529,   533,   534,   538,
-     539,   543,   547,   548,   549,   550,   551
+       0,   205,   205,   207,   212,   213,   214,   215,   216,   217,
+     218,   219,   220,   221,   222,   223,   224,   229,   249,   269,
+     289,   309,   330,   337,   344,   351,   362,   373,   392,   411,
+     433,   436,   442,   447,   452,   457,   462,   467,   472,   477,
+     482,   487,   495,   500,   505,   510,   514,   515,   519,   520,
+     521,   525,   526,   530,   531,   535,   536,   540,   541,   545,
+     546,   550,   554,   555,   556,   557,   558
 };
 #endif
 
@@ -1639,7 +1644,7 @@ yyreduce:
   switch (yyn)
     {
         case 17:
-#line 225 "parser.yy"
+#line 230 "parser.yy"
     {
 	      if (gengetopt_package_given)
 		{
@@ -1659,7 +1664,7 @@ yyreduce:
     break;
 
   case 18:
-#line 245 "parser.yy"
+#line 250 "parser.yy"
     {
 	      if (gengetopt_version_given)
 		{
@@ -1679,7 +1684,7 @@ yyreduce:
     break;
 
   case 19:
-#line 265 "parser.yy"
+#line 270 "parser.yy"
     {
 	      if (gengetopt_purpose_given)
 		{
@@ -1699,7 +1704,7 @@ yyreduce:
     break;
 
   case 20:
-#line 285 "parser.yy"
+#line 290 "parser.yy"
     {
 	      if (gengetopt_description_given)
 		{
@@ -1719,7 +1724,7 @@ yyreduce:
     break;
 
   case 21:
-#line 305 "parser.yy"
+#line 310 "parser.yy"
     {
       if (gengetopt_usage_given)
       {
@@ -1739,30 +1744,31 @@ yyreduce:
     break;
 
   case 22:
-#line 326 "parser.yy"
+#line 331 "parser.yy"
     {
                 gengetopt_set_section ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str));
               }
     break;
 
   case 23:
-#line 333 "parser.yy"
+#line 338 "parser.yy"
     {
   gengetopt_set_text((yyvsp[(2) - (2)].str));
-}
+            }
     break;
 
   case 24:
-#line 340 "parser.yy"
+#line 345 "parser.yy"
     {
   gengetopt_set_args((yyvsp[(2) - (2)].str));
-}
+            }
     break;
 
   case 25:
-#line 347 "parser.yy"
+#line 352 "parser.yy"
     {
-	      if (gengetopt_add_group ((yyvsp[(2) - (4)].str), (yyvsp[(3) - (4)].str), (yyvsp[(4) - (4)].boolean))) {
+              if (gengetopt_add_group ((yyvsp[(2) - (4)].str), (yyvsp[(3) - (4)].str), (yyvsp[(4) - (4)].boolean)))
+                {
 		  	yyerror ("group redefined");
 		  	YYERROR;
 		  }
@@ -1770,9 +1776,10 @@ yyreduce:
     break;
 
   case 26:
-#line 357 "parser.yy"
+#line 363 "parser.yy"
     {
-	      if (gengetopt_add_mode ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str))) {
+              if (gengetopt_add_mode ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str)))
+                {
 		  	yyerror ("mode redefined");
 		  	YYERROR;
 		  }
@@ -1780,7 +1787,7 @@ yyreduce:
     break;
 
   case 27:
-#line 368 "parser.yy"
+#line 375 "parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1798,7 +1805,7 @@ yyreduce:
     break;
 
   case 28:
-#line 387 "parser.yy"
+#line 394 "parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1816,7 +1823,7 @@ yyreduce:
     break;
 
   case 29:
-#line 406 "parser.yy"
+#line 413 "parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1834,7 +1841,7 @@ yyreduce:
     break;
 
   case 31:
-#line 430 "parser.yy"
+#line 437 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->required = (yyvsp[(2) - (2)].boolean);
@@ -1843,7 +1850,7 @@ yyreduce:
     break;
 
   case 32:
-#line 436 "parser.yy"
+#line 443 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type = (yyvsp[(2) - (2)].argtype);
@@ -1851,7 +1858,7 @@ yyreduce:
     break;
 
   case 33:
-#line 441 "parser.yy"
+#line 448 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type_str = strdup((yyvsp[(4) - (4)].str));
@@ -1859,7 +1866,7 @@ yyreduce:
     break;
 
   case 34:
-#line 446 "parser.yy"
+#line 453 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->details = strdup((yyvsp[(4) - (4)].str));
@@ -1867,7 +1874,7 @@ yyreduce:
     break;
 
   case 35:
-#line 451 "parser.yy"
+#line 458 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->acceptedvalues = (yyvsp[(4) - (4)].ValueList);
@@ -1875,7 +1882,7 @@ yyreduce:
     break;
 
   case 36:
-#line 456 "parser.yy"
+#line 463 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->default_string = strdup((yyvsp[(4) - (4)].str));
@@ -1883,7 +1890,7 @@ yyreduce:
     break;
 
   case 37:
-#line 461 "parser.yy"
+#line 468 "parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->group_value = strdup((yyvsp[(4) - (4)].str));
@@ -1891,7 +1898,7 @@ yyreduce:
     break;
 
   case 38:
-#line 466 "parser.yy"
+#line 473 "parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->mode_value = strdup((yyvsp[(4) - (4)].str));
@@ -1899,7 +1906,7 @@ yyreduce:
     break;
 
   case 39:
-#line 471 "parser.yy"
+#line 478 "parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->dependon = strdup((yyvsp[(4) - (4)].str));
@@ -1907,7 +1914,7 @@ yyreduce:
     break;
 
   case 40:
-#line 476 "parser.yy"
+#line 483 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->arg_is_optional = true;
@@ -1915,7 +1922,7 @@ yyreduce:
     break;
 
   case 41:
-#line 481 "parser.yy"
+#line 488 "parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (3)].gengetopt_option);
 			  	(yyval.gengetopt_option)->multiple = true;
@@ -1926,7 +1933,7 @@ yyreduce:
     break;
 
   case 42:
-#line 489 "parser.yy"
+#line 496 "parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->type = ARG_FLAG;
@@ -1934,7 +1941,7 @@ yyreduce:
     break;
 
   case 43:
-#line 494 "parser.yy"
+#line 501 "parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->hidden = true;
@@ -1942,7 +1949,7 @@ yyreduce:
     break;
 
   case 44:
-#line 499 "parser.yy"
+#line 506 "parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->flagstat = (yyvsp[(2) - (2)].boolean);
@@ -1950,118 +1957,118 @@ yyreduce:
     break;
 
   case 45:
-#line 503 "parser.yy"
+#line 510 "parser.yy"
     { (yyval.gengetopt_option) = new gengetopt_option; }
     break;
 
   case 46:
-#line 507 "parser.yy"
+#line 514 "parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 47:
-#line 508 "parser.yy"
+#line 515 "parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 48:
-#line 512 "parser.yy"
-    { (yyval.boolean) = 0; }
-    break;
-
-  case 49:
-#line 513 "parser.yy"
-    { (yyval.boolean) = 1; }
-    break;
-
-  case 50:
-#line 514 "parser.yy"
-    { (yyval.boolean) = 0; }
-    break;
-
-  case 51:
-#line 518 "parser.yy"
-    { (yyval.boolean) = 1; }
-    break;
-
-  case 52:
 #line 519 "parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
+  case 49:
+#line 520 "parser.yy"
+    { (yyval.boolean) = 1; }
+    break;
+
+  case 50:
+#line 521 "parser.yy"
+    { (yyval.boolean) = 0; }
+    break;
+
+  case 51:
+#line 525 "parser.yy"
+    { (yyval.boolean) = 1; }
+    break;
+
+  case 52:
+#line 526 "parser.yy"
+    { (yyval.boolean) = 0; }
+    break;
+
   case 53:
-#line 523 "parser.yy"
+#line 530 "parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 54:
-#line 524 "parser.yy"
+#line 531 "parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 55:
-#line 528 "parser.yy"
+#line 535 "parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 56:
-#line 529 "parser.yy"
+#line 536 "parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 57:
-#line 533 "parser.yy"
+#line 540 "parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 58:
-#line 534 "parser.yy"
+#line 541 "parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 59:
-#line 538 "parser.yy"
+#line 545 "parser.yy"
     { (yyval.ValueList) = new AcceptedValues; (yyval.ValueList)->insert((yyvsp[(1) - (1)].str)); }
     break;
 
   case 60:
-#line 539 "parser.yy"
+#line 546 "parser.yy"
     { (yyvsp[(1) - (3)].ValueList)->insert((yyvsp[(3) - (3)].str)); (yyval.ValueList) = (yyvsp[(1) - (3)].ValueList); }
     break;
 
   case 61:
-#line 543 "parser.yy"
+#line 550 "parser.yy"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 62:
-#line 547 "parser.yy"
+#line 554 "parser.yy"
     { (yyval.multiple_size) = new multiple_size; }
     break;
 
   case 63:
-#line 548 "parser.yy"
+#line 555 "parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (3)].str), (yyvsp[(2) - (3)].str)); }
     break;
 
   case 64:
-#line 549 "parser.yy"
+#line 556 "parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (4)].str), "0"); free((yyvsp[(2) - (4)].str)); }
     break;
 
   case 65:
-#line 550 "parser.yy"
+#line 557 "parser.yy"
     { (yyval.multiple_size) = new multiple_size("0", (yyvsp[(3) - (4)].str)); free((yyvsp[(3) - (4)].str)); }
     break;
 
   case 66:
-#line 551 "parser.yy"
+#line 558 "parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (5)].str), (yyvsp[(4) - (5)].str)); free((yyvsp[(2) - (5)].str)); free((yyvsp[(4) - (5)].str)); }
     break;
 
 
 /* Line 1267 of yacc.c.  */
-#line 2065 "parser.cc"
+#line 2072 "parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2281,6 +2288,6 @@ yyreturn:
 }
 
 
-#line 554 "parser.yy"
+#line 561 "parser.yy"
 
 
