@@ -9,11 +9,17 @@
 
 #define PRINT_OPTION(s) printf("%s: %s\n", # s, args_info.s)
 
+#ifndef FIX_UNUSED
+#define FIX_UNUSED(X) (void) (X)
+#endif // FIX_UNUSED
+
 static struct gengetopt_args_info args_info;
 
 int
 main (int argc, char **argv)
 {  
+  FIX_UNUSED (argc);
+  FIX_UNUSED (argv);
   test_all_opts_cmd_parser_init (&args_info);
 
   PRINT_OPTION(help_help);
